Ad class sealed

An ad.

This is the base class for all CrossPromote ads.

See also:

  • ImageAd for standard image ads.
  • MetadataAd for ads that are not directly displayed to the user, but can be used to display custom content.
  • EmptyAd for ads that are not available.

Properties

hashCode int
The hash code for this object.
no setterinherited
payload Map<String, dynamic>
Custom payload associated with the ad.
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
targetUrl String?
The URL to redirect to when the ad is clicked.
final
type AdType
The type of the ad.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited