targetUrl property
The URL to redirect to when the ad is clicked.
Required for image ads, optional for metadata ads.
Implementation
final String? targetUrl;
The URL to redirect to when the ad is clicked.
Required for image ads, optional for metadata ads.
final String? targetUrl;