ImageAd class final

An image ad.

Inheritance

Constructors

ImageAd({required AdSize size, required Map<String, dynamic> payload, required String imageUrl, required String targetUrl})
Creates an image ad.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
imageUrl String
The URL of the image to display.
final
payload Map<String, dynamic>
Custom payload associated with the ad.
finalinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size AdSize
The size of the ad.
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
targetUrl String
The URL to redirect to when the ad is clicked.
no setteroverride
type AdType
The type of the ad.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited